splitter#sidebar-splitter {
	margin-right: 2px;
	margin-top: 2px;
	min-width: 8px;
	max-width: 8px;
	padding: 0px;
	border: none;
	background-color: #003366;
}

splitter#sidebar-splitter #bottomright-cap {
	min-height: 8px; 
	background-image: url("chrome://sidebar/skin/sidebar-bottomright-cap.gif"); 
	background-repeat: no-repeat;
	background-position: 100% 100%;
}

splitter#sidebar-splitter #topright-cap {
	min-height: 8px; 
	background-image: url("chrome://sidebar/skin/sidebar-topright-cap.gif"); 
	background-repeat: no-repeat;
	background-position: 100% 0%;
}

splitter#sidebar-splitter grippy {
	margin: 0px;
	border: 2px solid #003366;
	padding: 0px;
	background-color: #6699CC;
	list-style-image: none;
}

splitter#sidebar-splitter grippy:hover {
	background-color: #99CCFF;
}

splitter#sidebar-splitter grippy:active {
	background-color: #99CCFF;
}


/**/

box#sidebar-box {
  margin-top: 2px;
  width: 162px;
  min-height: 1px;
  min-width: 10px;
  max-width: 400px;
  border: none;
  border-bottom: 8px solid #003366;
}

box#sidebar-panels {
  min-height: 1px;
}

box#sidebar-box[hidden="true"] {
  display: none;
}

splitter#sidebar-splitter[hidden="true"] {
  display: none;
}

iframe.panel-frame[collapsed="true"] {
  display: none;
}

/*
 *  Sidebar and Panel title buttons
 */
splitter.sidebar-main-header {
  color: #CCFFFF;
  background-color: #003366;
  padding: 0px;
  padding-left: 5px;
  padding-right: 5px;
}

splitter.sidebar-main-header div {
  font-weight: bold;
  margin: 2px;
}

splitter.sidebar-main-header titledbutton {
  padding: 0px;
}

splitter.sidebar-main-header titledbutton:hover {
  color: white;
}

titledbutton.panel-bar {
  padding: 0px;
  margin: 0px;
  border-top: 1px solid white;
  background-color: #CCCCCC;
  padding: 0px;
  padding-left: 5px;
  padding-right: 5px;
  font-size: smaller;
}
