window { 
  display                     : block;
  width                       : 100%;
} 

box {
  width                       : 100%;
  height                      : 100%;
  display                     : block;
}

box.picker {
  margin-left                 : 10px;
  margin-top                  : 10px;
  margin-bottom               : 5px;
  margin-right                : 20px;
}

div {
  cursor                      : default;
  padding                     : 10px;
}

div.dirLabel {
  margin-left                 : 15px;
  font-weight                 : bold;
}

div.input1 {
  margin-left                 : 5px;
  margin-top                  : 0px;
  padding                     : 0px;
}

titledbutton.active { 
  border                      : 0px;
  margin                      : 2px; 
  padding                     : 3px 13px 0px 11px
}

titledbutton[disabled] { 
  color                       : black;
}

titledbutton#ProfileDir {
  border                      : none;
  color                       : black;
  font-weight                 : bold;
  padding                     : none;
  margin                      : none;
  text-decoration             : none;
}

titledbutton { 
  color                       : black;
  margin                      : 2px;
  padding                     : 2px 12px 1px 12px
}

box#folderbuttons {
  margin-top                  : 10px;
  margin-bottom               : -10px;
  margin-right                : 7px;
}

box#folderbuttons titledbutton {
  width                       : 90px;
}

box#dirbox {
  height                      : 50px;
}

span#deffoldername {
  margin-left                 : 2px;
} 
