/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Pete Collins, Ben Goodger
 */

/*
   THIS FILE IS LOCKED DOWN.  YOU ARE NOT ALLOWED TO MODIFY IT WITHOUT FIRST HAVING YOUR
   CHANGES REVIEWED BY cmanske@netscape.com.
*/


/* HTML ELEMENTS */

table { cell-spacing: 0px; }
td, table { border: 0px;}

/* Use to center vertically in a table cell */
tr { 
  vertical-align: middle;
}

select.SpellCheckList, select.SpellCheckLanguage, input.SpellCheckWord {
    width: 20em;
}

select.dialog {
	font-size: smaller;
}

div.spacer [align~=horizontal] {
    border:  1px inset white;
    height:  2px;
}

div#message {
  width:       20em; 
  margin-left: 10px

}

/* XUL ELEMENTS */

/* values = margin, padding. Padding doesn't work yet */

/* Should be in XUL.css? */
tab {
    padding: 0px 3px;
}

select#alignTypeSelect,label#alignLabel {
  margin-left: 5px;
}

titledbutton#AdvancedEdit {
  margin-left: 6px;
  min-width: 10em;
}

titledbutton#MoreFewerButton[more="0"] {
  margin-left: 6px;
  list-style-image: url(chrome://global/skin/scroll-down.gif);
  /* use this after Eric fixes button width bug */
  /* width: 10em */
}
titledbutton#MoreFewerButton[more="1"] {
  margin-left: 6px;
  list-style-image: url(chrome://global/skin/scroll-up.gif);
  /* width: 10em */
}

/* THIS SHOULD BE IN GLOBAL.CSS */
label.dialog[disabled],legend.dialog[disabled] {
    color: gray;
}

/* Link Properties */
titledbutton#SaveDefault {
  margin-right: 6px;
  width: 7em;
}

titledbutton[class~=SizeToParent] {
  width: 100%;
}

spring.spacer {
      width:  5px;
      height: 5px;
}

spring.bigspacer {
      width:  10px;
      height: 10px;
}

box.tabpanel {
  border: 1px outset #CCCCDD;
  padding: 10px;
}

img.AlignIcon {
  margin-right: 5px;
  /* To make all align the same */
  /*vertical-align: middle;*/
}

titledbutton#img-align-top {
	list-style-image:url("chrome://editor/skin/images/img-align-top.gif");
}
titledbutton#img-align-middle {
	list-style-image:url("chrome://editor/skin/images/img-align-middle.gif");
}
titledbutton#img-align-bottom {
	list-style-image:url("chrome://editor/skin/images/img-align-bottom.gif");
}
titledbutton#img-align-left {
	list-style-image:url("chrome://editor/skin/images/img-align-left.gif");
}
titledbutton#img-align-right {
	list-style-image:url("chrome://editor/skin/images/img-align-right.gif");
}

/* Rest are from Ben Goodger for Advanced Edit dialog 
   These need reviewing and eliminate all but essential attributes */

div.tagname {
    font-weight: bold;
    /*font-size  : 17px;*/
}

div#tagLabel {
    font-weight: bold;
}

/* styles for an attribute tree-table */
tree.AttributesTree {
    min-width : 200px;
    min-height: 200px;
    border    : 1px inset white;
}

tree.AttributesTree treecell {
    color         : black;
    padding-left  : 10px;
    padding-top   : 2px;
    padding-bottom: 2px;
    padding-right : 2px;
}

tree.AttributesTree > treehead > treerow > treecell {
    border          : 1px outset white;
    background-color: #CCCCDD;
}

tree.AttributesTree > treehead > treerow > treecell:active {
    border-left   : 1px inset white; /*inset white;*/
    border-top    : 1px inset white;
    border-right  : 1px solid #CCCCDD;
    border-bottom : 1px solid #CCCCDD;
    padding-left  : 11px;
    padding-top   : 3px;
    padding-right : 1px;
    padding-bottom: 1px;
}


/* FILES/MOZILLAE/M96/BIN/chrome/editor/content/default/EdAdvancedEdit.xul */
tree.AttributesTree treechildren > treeitem > treerow > treecell {
    border-right    : 1px solid #CCCCDD;
    border-bottom   : 1px solid #CCCCDD;
    color           : black;
    background-color: #FFFFFF;
    padding-left    : 10px;
    padding-top     : 2px;
    padding-bottom  : 2px;
    padding-right   : 2px;
}

tree.AttributesTree treechildren > treeitem > treerow > treecell.value {
    border-bottom   : 1px solid #CCCCDD;
    color           : black;
    background-color: #FFFFFF;
    padding-left    : 0px;
    padding-top     : 0px;
    padding-bottom  : 0px;
    padding-right   : 0px;
    margin-left     : 0px;
}


tree.AttributesTree treechildren > treeitem > treerow [selected ~= false] {
    color           : black;
    background-color: #FFFFFF;
}

tree.AttributesTree treechildren > treeitem > treerow [selected ~= true] {
    color           : white;
    background-color: #666699;
}

input.AttributesCell {
    width : 95%;
    border: none;
    height: 100%;
}

treecell input:hover {
    background-color: #ECECEC;
    font-weight     : bold;
    border          : 2px solid #666699;
}
