/** this should only contain XUL dialog and document window widget defaults. Defaults for widgets of
    a particular application should be in that application's style sheet.
	For example style definitions for navigator can be found in navigator.css

   THIS FILE IS LOCKED DOWN.  YOU ARE NOT ALLOWED TO MODIFY IT WITHOUT FIRST HAVING YOUR
   CHANGES REVIEWED BY hyatt@netscape.com.
**/

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to HTML */
@namespace html url("http://www.w3.org/TR/REC-html40"); /* namespace for XUL elements */

/**********************************
 * Window
 **********************************/

/**
 * The is the outer most tag in a xul document all xul
 * content will be inside it.
 */
window { 
  background-color: white;
  font: 3mm arial,helvetica,sans-serif;
  padding: 0px;
}

/**
 * This is a special class of window used for dialogs
 */
window.dialog { 
  background-color: #CCCCCC;
  /* There is a bug preventing this so this will not work property.
  padding-left: 11px;
  padding-right: 10px;
  padding-top: 10px;
  padding-bottom: 11px;
  */
}

/**********************************
 * XUL widgets
 **********************************/

/******** Box *********/


/* Conditional debug */

*[debug="true"]:-moz-horizontal-box-debug {
  border: 2px solid blue;
  border-top-width: 10px;
  color: white;
  padding: 2px;
  margin: 2px;
}

*[debug="true"]:-moz-vertical-box-debug {
  border: 2px solid red;
  border-left-width: 10px;
  color: white;
  padding: 2px;
  margin: 2px;
}

*[debug="true"] *:-moz-horizontal-box-debug {
  border: 2px solid blue;
  border-top-width: 10px;
  color: white;
  padding: 2px;
  margin: 2px;
}

*[debug="true"] *:-moz-vertical-box-debug {
  border: 2px solid red;
  border-left-width: 10px;
  color: white;
  padding: 2px;
  margin: 2px;
}

/* comment this in to make all boxes show their
   debug info automatically. Otherwise use debug="true"
   to show it and use the rules above.

*:-moz-horizontal-box-debug {
  border: 2px solid blue;
  border-top-width: 10px;
  padding: 2px;
  color: white;
}

*:-moz-vertical-box-debug {
  border: 2px solid red;
  border-left-width: 10px;
  padding: 2px;
  color: white;
}
*/


/******* ToolBox & ToolBar *******/

toolbox { 
  background-color:#999999; 
} 

:toolbox-normal { 
  background-color: #003366; 
  background-image: url("chrome://global/skin/taskbar-tab.gif"); 
  background-repeat: no-repeat; 
} 

:toolbox-rollover { 
  background-color: #99cccc; 
  background-image: url("chrome://global/skin/taskbar-tab-hover.gif"); 
  background-repeat: no-repeat; 
} 

toolbar.standard {
	color: white;
	background-color: #003366;
	padding: 0px;
	margin: 0px;
	border: none;
	min-height: 46px;
}

/**
 * round buttons used in 'standard toolbar'
 */
titledbutton.button28 {
	background-image: url("chrome://global/skin/button28-bg.gif");
	background-repeat: no-repeat;
	background-position: 50% 4px;
	background-color: transparent;
	color: #CCFFFF;
	border: none;
	padding: 0px;
	min-width: 28px;
	margin: 3px 7px 1px 1px;
	font-size: smaller;
}

titledbutton.button28:hover {
	background-image:url("chrome://global/skin/button28-bg-hover.gif");
	border: none;
	color: #CCFFFF;
	text-decoration: none;
}

titledbutton.button28:active {
	background-image:url("chrome://global/skin/button28-bg-active.gif");
	border: none;
	color: #CCFFFF;
	text-decoration: none;
}

titledbutton.button28[disabled="true"] {
	background-image:url("chrome://global/skin/button28-bg-disabled.gif");
	border: none;
	color: #669999;
	text-decoration: none;
}

titledbutton.button28[disabled="true"]:hover {
	background-image:url("chrome://global/skin/button28-bg-disabled.gif");
	border: none;
	color: #669999;
	text-decoration: none;
}

titledbutton.button28[disabled="true"]:active {
	background-image:url("chrome://global/skin/button28-bg-disabled.gif");
	border: none;
	color: #669999;
	text-decoration: none;
}


/**
 * normal buttons used in 'standard toolbar'
 */
titledbutton.other28 {
	background-image: none;
	background-color: transparent;
	color: #CCFFFF;
	border: none;
	padding: 0px;
	min-width: 28px;
	margin: 3px 7px 1px 1px;
	font-size: smaller;
}

titledbutton.other28:hover {
	background-image:url("chrome://global/skin/otherbutton28-bg-hover.gif");
	background-repeat: no-repeat;
	background-position: 50% 4px;
	color: #CCFFFF;
	border: none;
	text-decoration: none;
}

titledbutton.other28:active {
	background-image:url("chrome://global/skin/otherbutton28-bg-active.gif");
	background-repeat: no-repeat;
	background-position: 50% 4px;
	color: #CCFFFF;
	border: none;
	text-decoration: none;
	margin: 4px 6px 0px 2px;
}

titledbutton.other28[disabled="true"] { 
	margin: 3px 7px 1px 1px;
	color: #669999;
	border: none;
	text-decoration: none;
}

titledbutton.other28[disabled="true"]:hover {
	background-image: none;
	color: #669999;
	border: none;
	text-decoration: none;
}

titledbutton.other28[disabled="true"]:active {
	background-image: none;
	color: #669999;
	border: none;
	text-decoration: none;
}

/**
 * 32px round buttons (used in Navigation Toolbar)
 */
/* have to explicitly set the border and padding to ensure that more specific rules 
   for disabled and active titledbuttons don't apply */
titledbutton.button32 {
	background-repeat: no-repeat;
	background-position: 50% 0px;
	background-color: transparent;
	color: #CCFFFF;
	min-width: 36px;
	min-height: 36px;
	border: none;
	padding: 0px;
	margin-left: 1px;
	margin-bottom: 1px;
	margin-top: 6px;
	margin-right: 6px;
	font-size: smaller;
	background-image:url("chrome://global/skin/button32-bg.gif");
}

titledbutton.button32:hover {
	border: none;
	padding: 0px;
	margin-left: 1px;
	margin-bottom: 1px;
	margin-top: 6px;
	margin-right: 6px;
	background-image:url("chrome://global/skin/button32-bg-hover.gif");
}

titledbutton.button32:active {
	border: none;
	padding: 0px;
	margin-top: 7px;
	margin-left: 2px;
	margin-bottom: 0px;
	margin-right: 5px;
	background-image:url("chrome://global/skin/button32-bg-active.gif");
}

titledbutton.button32[disabled="true"] {
	border: none;
	padding: 0px;
	margin-left: 1px;
	margin-bottom: 1px;
	margin-top: 6px;
	margin-right: 6px;
	background-image:url("chrome://global/skin/button32-bg-disabled.gif");
}

titledbutton.button32[disabled="true"]:hover {
	border: none;
	padding: 0px;
	margin-left: 1px;
	margin-bottom: 1px;
	margin-top: 6px;
	margin-right: 6px;
	background-image:url("chrome://global/skin/button32-bg-disabled.gif");
}

titledbutton.button32[disabled="true"]:active {
	border: none;
	padding: 0px;
	margin-left: 1px;
	margin-bottom: 1px;
	margin-top: 6px;
	margin-right: 6px;
	background-image:url("chrome://global/skin/button32-bg-disabled.gif");
}

/**
 * Throbber
 */
/* FIX ME - move these gifs to global */
titledbutton#Throbber {
	border: none;
	margin-top: 8px;
	margin-left: 9px;
	list-style-image: url("chrome://global/skin/animthrob_single.gif");
	background-image: none;
}

titledbutton#Throbber:active {
	margin-top: 9px;
	margin-left: 10px;
}

titledbutton#Throbber[busy="true"] {
	list-style-image:url("chrome://global/skin/animthrob.gif");
}


toolbar {
    background-color: #CCCCCC;
}

toolbar.standard #toolbar_throbber_box { 
	background-color: #CCCCCC;
	min-width: 59px;
	max-width: 59px;
	background-image: url("chrome://global/skin/n-box.gif");
	background-repeat: no-repeat;
	background-position: 100% 0%;
}

titledbutton.toolbar {
  border: 1px solid transparent;
}

titledbutton.toolbar:hover {
  border: 1px outset white;
  color:#333366;
  text-decoration: underline;
}
 
titledbutton.toolbar:hover:-moz-outline {
   border : 1px solid black;
}
 
titledbutton.toolbar:active {
  text-decoration:none;
  border: 1px inset;
}

titledbutton.toolbar:active:-moz-outline {
   border : 1px solid black;
}
 
titledbutton.toolbar[disabled="true"] {
	border: 1px solid transparent;
}

titledbutton.toolbar[disabled="true"]:hover {
	border: 1px solid transparent;
}

titledbutton.toolbar[disabled="true"]:active {
	border: 1px solid transparent;
	padding: 2px;
}


/**
 * status-bar
 */
box#status-bar {
	min-width: 1em;
	background-color: #CCCCCC;
}

titledbutton.status-bar {
	border: none;
	padding: 0px;
	margin: 0px;
	min-width: 3em;
}

titledbutton.status-bar:hover {
     text-decoration: none;
}

/* removing margin and padding from normal mousedown titledbutton behavior */
titledbutton.status-bar:active {
	border: none;
	padding: 0px;
	margin: 0px;
}

#status-bar-leftcap {
	min-width: 8px;
	max-width: 8px;
	background-image: url("chrome://global/skin/gray-bottomleft.gif");
	background-position: 0% 100%;
	background-repeat: no-repeat;
}

#status-bar-rightcap {
	min-width: 8px;
	max-width: 8px;
	background-image: url("chrome://global/skin/gray-bottomright.gif");
	background-position: 100% 100%;
	background-repeat: no-repeat;
}

/******* Splitters *******/

splitter {
   cursor: arrow;
   min-width: 5px;
   min-height: 5px;
}

grippy{
	margin: 0px;
	border: 2px solid #003366;
	padding: 0px;
	background-color: #6699CC;
	list-style-image: none;
}

grippy:hover{
	background-color: #99CCFF;
}

grippy:active{
	background-color: #99CCFF;
}

box[align="vertical"]>splitter grippy {
	/* a horizontal splitter */
	min-width: 60px;
	max-height: 4px;
}

box[align="horizontal"]>splitter grippy {
	/* a vertical splitter */
	max-width: 4px;
	min-height: 60px;
}

window[align="vertical"]>splitter grippy {
	/* a horizontal splitter */
	min-width: 60px;
	max-height: 4px;
}

window[align="horizontal"]>splitter grippy {
	/* a vertical splitter */
	max-width: 4px;
	min-height: 60px;
}


/**
 * gray horizontal splitter for pane views
 */
splitter.gray-horizontal-splitter { 
	min-height: 8px;
	background-color: #CCCCCC;
	border: none;
	padding: 0px;
}

splitter.gray-horizontal-splitter grippy { 
	margin: 0px;
	border: 2px solid #CCCCCC;
	padding: 0px;
	background-color: #6699CC;
	list-style-image: none;
}
splitter.gray-horizontal-splitter grippy:hover { 
	background-color: #003366;
}

splitter.gray-horizontal-splitter grippy:active { 
	background-color: #003366;
}

splitter.gray-horizontal-splitter #begincap { 
	min-width: 8px;
	max-width: 8px;
	background-image: url("chrome://global/skin/gray-bottomleft.gif");
	background-repeat: no-repeat;
	background-position: 0% 100%;
}

splitter.gray-horizontal-splitter #endcap { 
	min-width: 8px;
	max-width: 8px;
}


/****** Progress Meter ********/

progressmeter[align="horizontal"] {
	height: 1em;
}

progressmeter {
	color : #9999CC;
	background-color: #999999;
}

:progressmeter-stripe {
	color: #CCCCCC;
}

/********* XP Menus ***********/

menu {
	color: black;
}

menu[disabled="true"] {
	color: #999999;
}

menuitem {
	color: black;
}

menuitem[disabled="true"] {
	color: #999999;
}

/* XXX menupopups have to have a color explicitly specified. this is a bug */
menupopup, popup {
  background-color: white;
  border: 1px white outset;
}

popup {
  background-color: white;
}

menupopup > menu {
  max-width: 400px;
  min-width: 125px;
  margin-left: 1px;
  margin-right: 1px;
  margin-top: 0px;
  margin-bottom: 0px;
}

popup > menu {
  max-width: 400px;
  min-width: 125px;
  margin-left: 1px;
  margin-right: 1px;
  margin-top: 0px;
  margin-bottom: 0px;
}

menupopup > menuitem {
  max-width: 400px;
  min-width: 125px;
  margin-left: 1px;
  margin-right: 1px;
  margin-top: 0px;
  margin-bottom: 0px;
}

popup > menuitem {
  max-width: 400px;
  min-width: 125px;
  margin-left: 1px;
  margin-right: 1px;
  margin-top: 0px;
  margin-bottom: 0px;
}

menuseparator {
  border-bottom: 1px white solid; 
  border-top: 1px gray solid; 
  margin: 2px;
}

toolbarseparator { 
  min-width: 2em; 
  max-width: 2em;
  width: 2em; 
}

menubar > menu {
  border: 1px solid transparent;
  padding-top: 2px;
  padding-bottom: 2px;
  padding-left: 3px;
  padding-right: 3px;
  margin-top: 2px;
  margin-bottom: 2px;
}

menupopup > menu {
  border: 1px solid transparent;
  padding: 2px;
}

menupopup > menuitem {
  border: 1px solid transparent;
  padding: 2px;
}

popup > menuitem {
  border: 1px solid transparent;
  padding: 2px;
}

menubar > menu[menuactive="true"] {
  border: 1px outset white;
  color:#333366;
}

menubar > menu[menuactive="true"][open="true"] {
  border: 1px inset;
}

menupopup > menu[menuactive="true"] {
  background-color: #003366;
  color: white;
}

popup > menu[menuactive="true"] {
  background-color: #003366;
  color: white;
}

menupopup > menuitem[menuactive="true"] {
  background-color: #003366;
  color: white;
}

popup > menuitem[menuactive="true"] {
  background-color: #003366;
  color: white;
}

.menu-right {
  padding: 0px;
  border: 0px;
  width: 10px;
  margin-top: 0px;
  margin-bottom: 0px;
  margin-left: 6px;
  margin-right: 0px;
}

.menu-left {
  color: inherit;
  padding: 0px;
  border: 0px;
  width: 13px;
  margin-top: 0px;
  margin-bottom: 0px;
  margin-right: 2px;
}

.menubar-left {
  color: inherit;
  padding: 0px;
  border: 0px;
  margin-top: 0px;
  margin-bottom: 0px;
  margin-right: 2px;
}

.menu-text, .menu-accel {
  color: inherit;
  padding: 0px;
  border: 0px;
  margin-top: 0px;
  margin-bottom: 0px;
  margin-right: 2px;
}

.menubar-text {
  color: inherit;
  padding: 0px;
  border: 0px;
  margin-top: 0px;
  margin-bottom: 0px;
  margin-right: 2px;
}

menuitem > .menu-right {
  list-style-image: none;
}

menuitem > .menu-left {
  list-style-image: none;
}

menuitem[checked="true"] > .menu-left {
  list-style-image: url("chrome://global/skin/menu-check.gif");
}

menuitem[checked="true"][disabled="true"] > .menu-left {
  list-style-image: url("chrome://global/skin/menu-check-disabled.gif");
}

menuitem[checked="true"][menuactive="true"] > .menu-left {
  list-style-image: url("chrome://global/skin/menu-check-hover.gif");
}

menu > .menu-right {
  list-style-image: url("chrome://global/skin/menu-arrow.gif");
}

menu[menuactive="true"] > .menu-right {
  list-style-image: url("chrome://global/skin/menu-arrow-hover.gif");
}


/******** Titled buttons **********/

titledbutton.push {
  border: 1px outset white;
  padding: 2px;
  margin: 2px;
  text-align: center;
  background-color:inherit;
  background-image: inherit;
}

titledbutton.push:hover {
	border: 1px outset white;
	color:#003366;
	text-decoration:underline;
	padding: 2px;
}
 
titledbutton.push:hover:-moz-outline {
   border : 1px solid black;
   color:#003366;
   padding: 2px;
}
 
titledbutton.push:active {
  text-decoration:none;
  border: 1px inset;
  padding-left: 3px;
  padding-right: 1px;
  padding-top: 3px;
  padding-bottom: 1px;
}

titledbutton.push[toggled="1"] {
  border: 1px white inset;
  padding-left: 3px;
  padding-right: 1px;
  padding-top: 3px;
  padding-bottom: 1px;
}

titledbutton.push[toggled="2"] {
   background-color: lightgray;
   border: 1px solid gray;
}

titledbutton.push:active:-moz-outline {
   border : 1px solid black;
}
 
titledbutton.push[disabled="true"] {
	background-color:inherit;
  	background-image: inherit;
	border : 1px solid #999999;
	color: #999999;
	text-decoration: none;
}

titledbutton.push[disabled="true"]:hover {
  	background-color:inherit;
  	background-image: inherit;
	border : 1px solid #999999;
	color: #999999;
	text-decoration: none;
}

titledbutton.push[disabled="true"]:active {
  	background-color:inherit;
  	background-image: inherit;
	border : 1px solid #999999;
	color: #999999;
	text-decoration: none;
}

titledbutton.dialog {
  min-width: 5em;
}

titledbutton.dialog[default] {
	/* border-color: black; */
	font-weight: bold;
	list-style-image: url("chrome://global/skin/return.gif");
	
	/* FIX ME - temporary workaround to offset the lack of a way to align text and image */
	padding-right: 2em;
	max-width: 5em;
}

titledbutton[class~=popup] {
	list-style-image:url(chrome://global/skin/taskbar-popup-arrow.gif);
}

/* special class for plain titledbuttons */

titledbutton[class~="plain"] {
	border: 1px solid transparent;
	padding: 2px;
}

titledbutton[class~="plain"]:hover {
	border: 1px solid transparent;
	padding: 2px;
	text-decoration: none;
	color: inherit;
}
 
titledbutton[class~="plain"]:active {
	border: 1px solid transparent;
	padding: 2px;
	text-decoration: none;
	color: inherit;
}

titledbutton[class~="plain"][disabled] {
	border: 1px solid transparent;
	padding: 2px;
}

titledbutton[class~="plain"][disabled]:hover {
	border: 1px solid transparent;
	padding: 2px;
}

titledbutton[class~="plain"][disabled]:active {
	border: 1px solid transparent;
	padding: 2px;
}


/* special class for borderless buttons */
/* titled button on toolbars are automatically set to be borderless (see below) */

titledbutton[class~="borderless"] {
  border: 1px solid transparent;
}
 
titledbutton[class~="borderless"]:hover {
  border: 1px outset white;
  color:#333366;
  text-decoration: underline;
}
  
titledbutton[class~="borderless"]:hover:-moz-outline {
  border : 1px solid black;
}

titledbutton[class~="borderless"]:active {
  text-decoration:none;
  border: 1px inset;
}
 
titledbutton[class~="borderless"]:active:-moz-outline {
  border : 1px solid black;
}
 
titledbutton[class~="borderless"][disabled] {
  border: 1px solid transparent;
}

titledbutton[class~="borderless"][disabled]:hover {
  border: 1px solid transparent;
}

titledbutton[class~="borderless"][disabled]:active {
  border: 1px solid transparent;
  padding: 2px;
}

/******** Tree widget **********/

tree {
 background-color: white;
 border: none;
 border-spacing: 0px;
 width: 100%;
}

treeitem[selected="true"] > treerow { 
  color: white;
  background-color: #336699;
}

treecell { 
  white-space: nowrap;
  vertical-align: middle;
} 

treehead > treerow > treecell { 
  background-color: #CCCCCC; 
  color: black;
  border-right: 1px outset white;
  padding-left: 5px;
} 

treecell.image > titledbutton {
  border: 1px solid transparent;
  text-decoration: none;
  margin: 0px;
  padding: 0px;
}

treecell.image > titledbutton:hover {
  border: 1px solid transparent;
  text-decoration: none;
  margin: 0px;
  padding: 0px;
}
 
treecell.image > titledbutton:active {
  border: 1px solid transparent;
  text-decoration: none;
  margin: 0px;
  padding: 0px;
}

.tree-icon {
  width: 100%;
}

.tree-button {
 margin: 0px;
 padding: 0px;
 border: none;
 width: 100%;
 list-style-image: inherit;
}

.tree-button[flex] {
  width: 10px;
}

treecell {
 vertical-align: middle;
 padding-left: 2px;
}

treeitem > treerow > treecell > .tree-icon > .twisty {
 border: none;
 padding: 0px;
 margin: 0px;
 width: 16px;
 list-style-image: url("chrome://global/skin/closedtwisty.gif");
}

.twisty:hover {
 text-decoration: none;
}

.twisty:active {
 text-decoration: none;
}

treeitem[empty="true"] > treerow > treecell > .tree-icon > titledbutton.twisty {
 list-style-image: none;
}

treeitem > treerow > treecell > .tree-icon > .twisty[disabled="true"] {
 list-style-image: none;
}

treeitem[container="true"][open="true"] > treerow > treecell > .tree-icon > .twisty {
 list-style-image: url("chrome://global/skin/opentwisty.gif");
}


/********** Tab widget *********/

tab { 
  border: 1px outset white;
  /* -moz-border-radius: 90; */
  color:black; 
}

tab:active { 
  border: 1px outset white;
  /* -moz-border-radius: 90; */

  color:red; 
}

tabcontrol[align="vertical"] tabpanel + tabbox[align="horizontal"]  tab { 
	/* bottom tabs */
  border-left: 1px outset white;
  border-right: 1px outset white;
  border-top: none;
  border-bottom: 1px outset white;
  
  padding-right: 3px;
  padding-left: 3px;
  padding-top: 1px;
  padding-bottom: 3px;

  margin-right: 2px;
  margin-left: 2px;
  margin-top: 1px;
  margin-bottom: 1px;
}

tabcontrol[align="vertical"] tabbox[align="horizontal"] tab { 
  /* top tabs */
  border-left: 1px outset white;
  border-right: 1px outset white;
  border-top: 1px outset white;
  border-bottom: none;

  padding-right: 3px;
  padding-left: 3px;
  padding-top: 3px;
  padding-bottom: 1px;

  margin-right: 2px;
  margin-left: 2px;
  margin-top: 1px;
  margin-bottom: 1px;

}

tabcontrol[align="horizontal"] tabbox[align="vertical"] tab { 
	/* left tabs */
  border-left: 1px outset white;
  border-right: none;
  border-top: 1px outset white;
  border-bottom: 1px outset white;
  
  padding-right: 1px;
  padding-left: 3px;
  padding-top: 3px;
  padding-bottom: 3px;

  margin-right: 1px;
  margin-left: 1px;
  margin-top: 2px;
  margin-bottom: 2px;
  
}

tabcontrol[align="horizontal"] tabpanel + tabbox[align="vertical"]  tab { 
	/* right tabs */
  border-left: none;
  border-right: 1px outset white;
  border-top: 1px outset white;
  border-bottom: 1px outset white;
  
  padding-right: 3px;
  padding-left: 1px;
  padding-top: 3px;
  padding-bottom: 3px;

  margin-right: 1px;
  margin-left: 1px;
  margin-top: 2px;
  margin-bottom: 2px;
  
}

tab:hover { 
 color: #000033;
 text-decoration:underline;
}

tabcontrol { 
  border: none; 
}

/* when a tab is selected this is how it should look.
 */
tab[selected="true"] {
	font-weight: bold;
}


/********* XP Scrollbar *********/

thumb {
   background-color: #CCCCCC;
   border: 1px outset white;
   list-style-image: url("chrome://global/skin/scroll-thumb-horiz.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
thumb:hover {
   list-style-image: url(chrome://global/skin/scroll-thumb-horiz-hover.gif);
}
*/

thumb[disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-thumb-horiz-disabled.gif");
}

slider[align="vertical"] thumb {
   list-style-image: url("chrome://global/skin/scroll-thumb-vert.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
slider[align="vertical"] thumb:hover {
   list-style-image: url(chrome://global/skin/scroll-thumb-vert-hover.gif);

}
*/

slider[align="vertical"] thumb[disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-thumb-vert-disabled.gif");
}

thumb:active {
   background-color: #CCCCCC;
}

slider[align="vertical"] thumb:active {
   background-color: #CCCCCC;
}


slider {
   background-color: #999999;
}

scrollbarbutton {
  vertical-align: bottom;
  cursor: default;

  border: 1px outset white;
  background-color: #CCCCCC;
  color:black; 

  padding: 1px;
}

scrollbarbutton:active {
  border-style: inset;

  padding-left: 2px;
  padding-right: 0px;
  padding-top: 2px;
  padding-bottom: 0px;
}

scrollbarbutton[type="decrement"] {
   list-style-image: url("chrome://global/skin/scroll-left.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
scrollbarbutton[type="decrement"]:hover {
   list-style-image: url(chrome://global/skin/scroll-left-hover.gif)
}
*/

scrollbarbutton[type="decrement"][disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-left-disabled.gif") 
}

scrollbarbutton[type="increment"] {
   list-style-image: url("chrome://global/skin/scroll-right.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
scrollbarbutton[type="increment"]:hover {
   list-style-image: url(chrome://global/skin/scroll-right-hover.gif)
}
*/

scrollbarbutton[type="increment"][disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-right-disabled.gif") 
}


scrollbar[align="vertical"] scrollbarbutton[type="decrement"] {
   list-style-image: url("chrome://global/skin/scroll-up.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
scrollbar[align="vertical"] scrollbarbutton[type="decrement"]:hover {
   list-style-image: url(chrome://global/skin/scroll-up-hover.gif)
}
*/

scrollbar[align="vertical"] scrollbarbutton[type="decrement"][disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-up-disabled.gif") 
}

scrollbar[align="vertical"] scrollbarbutton[type="increment"] {
   list-style-image: url("chrome://global/skin/scroll-down.gif")
}

/*
pinkerton - workaround. removed until bug 15722 can be fixed.
scrollbar[align="vertical"] scrollbarbutton[type="increment"]:hover {
   list-style-image: url(chrome://global/skin/scroll-down-hover.gif)
}
*/

scrollbar[align="vertical"] scrollbarbutton[type="increment"][disabled="true"] {
   list-style-image: url("chrome://global/skin/scroll-down-disabled.gif") 
}




/**********************************
 * HTML components in the window tag
 **********************************/

/**
 * removed 2px black border from iframe
 */
window html|iframe {
 min-width: 10px;
 min-height: 10px;
 width: 100px;
 height: 100px;
 border: none;
}

window html|div.separator[align="horizontal"] { 
	 width: 100%; 
	 max-height: 2px; 
	 vertical-align: middle; 
	 border-bottom: 2px groove white; 
	 margin-top: 0.5em; 
	 margin-bottom: 0.5em; 
	 margin-left: 0.25em; 
	 margin-right: 0.25em; 
} 

window html|div.separator[align="vertical"] { 
	 height: 100%; 
	 max-width: 2px; 
	 border-right: 2px groove white; 
	 background-color: yellow; 
	 margin-left: 0.5em; 
	 margin-right: 0.5em; 
	 margin-top: 0.25em; 
	 margin-bottom: 0.25em; 
}


window html|fieldset {
	margin-bottom: 6px;
	margin-top: 5px;
	margin-left: 6px;
	margin-right: 5px;
	padding: 5px; 
	border: 2px groove white;
}


window html|legend {
	border: none;
	margin-bottom: 5px;
	margin-top: 0px;
	margin-left: 4px;
	margin-right: 3px;
}

window html|label {
	padding-bottom: 4px;
	background-color: transparent;
	white-space: nowrap;
}

window html|textarea {
  border: 1px inset #DDDDDD;
  padding-top: 1px;
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 3px;
  margin-top: 1px;
  margin-bottom: 2px;
  margin-left: 4px;
  margin-right: 3px;
  background-color: white;
  color: black;
}

window html|input[type=text] {
  border: 1px inset rgb(192, 192, 192);
  padding-top: 1px;
  padding-bottom: 1px;
  padding-left: 1px;
  padding-right: 1px;
  margin-top: 0px;
  margin-bottom: 2px;
  margin-left: 4px;
  margin-right: 3px;
  background-color: white;
  color: black;
  min-height: 1.6em;
}

window html|input[type=password] {
  border: 1px inset rgb(192, 192, 192);
  padding-top: 3px;
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 3px;
  margin-top: 1px;
  margin-bottom: 2px;
  margin-left: 4px;
  margin-right: 3px;
  background-color: white;
  color: black;
  min-height: 1.75em;
}

window html|input {
  background-color: transparent;
  color: black;
}

window html|input[type=radio] {
  margin-left:   3px;   
  margin-right:  5px;  
  margin-top:    3px; 
  margin-bottom: 3px; 
  color:black;
  width:12px;
  height:12px;
}

window html|input[type=checkbox] {
  margin-left:   3px;   
  margin-right:  5px;  
  margin-top:    3px; 
  margin-bottom: 4px;
  border: 1px inset rgb(192, 192, 192);
  color:black;
}
