/* 
 * Window behavior for scrolling and general header color
 * attributes
 */
window          { overflow: auto; }
mailheader      { display: block; }
mailattachcount { display: none; }

box[name=header-attachment] { background-color: #EFEFEF; border: 0px solid #EFEFEF; border-left-width: 4px; }
box[name=header-part1]      { background-color: #EFEFEF; border: 0px solid #EFEFEF; border-left-width: 4px; }
box[name=header-part2]      { background-color: #DEDEDE; border: 0px solid #DEDEDE; border-left-width: 4px; }
box[name=header-part3]      { background-color: #DEDEDE; border: 0px solid #DEDEDE; border-left-width: 4px; }
box[name=header-seamonkey]  { background-color: #DEDEDE; border: 0px solid #DEDEDE; border-left-width: 4px; }

menubar[name=attachment-menubar]  { background-color: #EFEFEF; border: 0px solid #EFEFEF; }
menu[name=attachment-menu]        { background-color: #EFEFEF; border: 0px solid #EFEFEF; }

/**************************************************
 * These are all the headers that are displayed
 * for the normal header display. This is accomplished
 * by having a general header tag that turns off the
 * display of the field and then we selectively turn
 * on header displays. This will prevent unknown headers
 * from being displayed.
 **************************************************/

header                  { display: block; text-align: left; }
headerdisplayname       { font-weight: bold; white-space: pre; }

header[field=DATE]     { display: block; text-align:left; }

header[field=TO]        { display: block; text-align: left; }

header[field=FROM]        { display: block; text-align:left; }

header[field=SUBJECT] { display: block; text-align: left; font-weight: bold; }

header[field=CC] { display: block; text-align:left; }

header[field=BCC] { display: block; text-align:left; }

header[field=NEWSGROUPS] { display: block; text-align:left; }

header[field=ORGANIZATION] { display: block; text-align:left; }

header[field=USER-AGENT]   { display: block; text-align:left; }

/**************************************************
 * These are all the headers that are NOT displayed
 * for the normal header display
 **************************************************/
/* 
 * All misc headers (i.e. the ones that start with 
 * "X-" are turned off!
 */

header[field=RETURN-PATH] { display: block; text-align:left; }

header[field=STATUS] { display: block; text-align:left; }

header[field=RECEIVED] { display: block; text-align:left; }

header[field=MIME-VERSION] { display: block; text-align:left; }

header[field=PRECEDENCE] { display: block; text-align: left; }

header[field=CONTENT-BASE] { display: block; text-align:left; }

header[field=CONTENT-LOCATION] { display: block; text-align:left; }

header[field=CONTENT-ID] { display: block; text-align:left; }

header[field=CONTENT-DESCRIPTION] { display: block; text-align:left; }

header[field=CONTENT-DISPOSITION] { display: block; text-align:left; }

header[field=CONTENT-ENCODING] { display: block; text-align:left; }

header[field=CONTENT-LENGTH] { display: block; text-align:left; }

header[field=CONTENT-NAME] { display: block; text-align:left; }

header[field=CONTENT-TRANSFER-ENCODING] { display: block; text-align:left; }

header[field=CONTENT-TYPE] { display: block; text-align:left; }

header[field=DISTRIBUTION] { display: block; text-align:left; }

header[field=FCC] { display: block; text-align:left; }

header[field=FOLLOWUP-TO] { display: block; text-align:left; }

header[field=LINES] { display: block; text-align:left; }

header[field=MESSAGE-ID] { display: block; text-align:left; }

header[field=REFERENCES] { display: block; text-align:left; }

header[field=REPLY-TO] { display: block; text-align:left; }

header[field=RESENT-COMMENTS] { display: block; text-align:left; }

header[field=RESENT-DATE] { display: block; text-align:left; }

header[field=RESENT-FROM] { display: block; text-align:left; }

header[field=RESENT-MESSAGE-ID] { display: block; text-align:left; }

header[field=RESENT-SENDER] { display: block; text-align:left; }

header[field=RESENT-TO] { display: block; text-align:left; }

header[field=RESENT-CC] { display: block; text-align:left; }

header[field=SENDER] { display: block; text-align:left; }

header[field=XREF] { display: block; text-align:left; }

header[field=APPROVED-BY] { display: block; text-align:left; }

/**************************************************
 * These are all of the header extensions. For now,
 * these will be turned off and only display on the 
 * all header display
 **************************************************/

header[field=X-SUN-CHARSET] { display: block; text-align:left; }

header[field=X-SUN-CONTENT-LENGTH] { display: block; text-align:left; }

header[field=X-SUN-DATA-DESCRIPTION] { display: block; text-align:left; }

header[field=X-SUN-DATA-NAME] { display: block; text-align:left; }

header[field=X-SUN-DATA-TYPE] { display: block; text-align:left; }

header[field=X-SUN-ENCODING-INFO] { display: block; text-align:left; }

header[field=X-PRIORITY] { display: block; text-align:left; }

header[field=X-MOZILLA-PARTURL] { display: block; text-align:left; }

header[field=X-MOZILLA-DRAFT-INFO] { display: block; text-align:left; }

header[field=X-ACCEPT-LANGUAGE] { display: block; text-align:left; }

header[field=X-MAILING-LIST] { display: block; text-align:left; }

header[field=X-MAILING-LOOP] { display: block; text-align:left; }

header[field=X-LOOP] { display: block; text-align: left; }

header[field=X-MAILER] { display: block; text-align:left; }

header[field=X-MOZILLA-STATUS] { display: block; text-align:left; }

header[field=X-MOZILLA-STATUS2] { display: block; text-align: left; }

