window { 
 display: block;
 background-color: light-gray; 
 width: 100%;
} 

iframe {
  width: 100%;
  height: 100%;
  border: 1px outset #CCCCDD;
}

box {
  width: 100%;
  height: 100%;
  display: block;
}

box#header {
  background-color      : #FFFFFF;
  background            : url('chrome://profile/skin/header.gif');
  background-repeat     : no-repeat;
  background-position   : top left;
  padding-top           : 11px;
}

tab.selected {
  background-color            : #CCCCDD;
  margin                      : 0px 0px 0px 2px;
  padding-left                : 5px;
  padding-right               : 4px;
}

tab.nonselected {
  background-color            : transparent;
  color                       : #D4C8B8;
  margin                      : 0px 0px 0px 2px;
  padding-left                : 5px;
  padding-right               : 4px;
}

titledbutton.active { 
  border                      : 0px;
  margin                      : 2px; 
  padding                     : 3px 13px 0px 11px
}

titledbutton[disabled] { 
  color                       : black;
}

titledbutton { 
  color                       : black;
  width                       : 35px;
  margin                      : 2px;
  padding                     : 2px 12px 1px 12px
}

div#cplabel {
  font-family                 : serif;
  font-size                   : 26px;
  color                       : #61400A;
  font-weight                 : bold;
  letter-spacing              : 1px;
  margin-left                 : 20px;
  margin-bottom               : -7px;
}

div#cpsubl {
  font-family                 : serif;
  font-size                   : 14px;
  color                       : #AFA081;
  font-weight                 : bold;
  letter-spacing              : 1px;
  margin-left                 : 80px;
  margin-bottom               : 15px;
}
