/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 */

iframe#content-frame { 
  min-width: 100px; 
  min-height: 20px;
  height: 400px;
} 

toolbox#EditorToolbars {
  min-width: 20px;
}

toolbar#FormatToolbar {
  border-bottom: 1px solid #003366;
}

/* A small "toolbar" below content, above status */
box#DisplayModeBar {
  padding: 0px;
  /* Same as "standard" toolbar background */
  border-top: 1px solid #003366;
  border-bottom: 1px solid darkgray;
  margin-bottom: 0px;
  min-width:1em;
  color: white;
	background-color: #999999;
}

toolbar#FormatToolbar titledbutton.format {
  border: 1px solid transparent;
  margin: 1px 1px 1px 1px;
	padding: 2px;
	text-decoration: none;
	color: inherit;
}

toolbar#FormatToolbar titledbutton.format[toggled="1"] {
  border: 1px white inset;
}

toolbar#FormatToolbar titledbutton.format:hover {
/* What we should use, but this has a blue border that doesn't look good against gray toolbars 
	background-image:url("chrome://global/skin/otherbutton28-bg-hover.gif");
	background-image:url("chrome://editor/skin/images/hover-teal.gif");
	background-repeat: no-repeat;
  background-position: center center;
*/
  border: 1px solid white;
	text-decoration: none;
  /* global class="plain" should do this! */
}

toolbar#FormatToolbar titledbutton[class~=format]:active {
  margin: 2px 0px 0px 2px;
}

toolbar#FormatToolbar titledbutton[class~=TextAttribute] {
	/* Make these narrower */
  padding: 2px 0px;
  min-width: 18px; 
  width: 18px; 
  /*height: 16px; */
  /* padding: 2px 0px 0px 0px;*/
  font-size: 19px; 
  font-family: times, serif, sans-serif;
}

toolbar#FormatToolbar titledbutton#boldButton {
  font-weight: bold; 
}

toolbar#FormatToolbar titledbutton#italicButton {
  font-weight: bold; 
  font-style:  italic;
}

toolbar#FormatToolbar titledbutton#underlineButton {
  font-weight: normal; 
  text-decoration: underline;
}

div.toolbar-middle {
  /* trying to center vertically in the toolbar! */
  vertical-align: middle;
}
select.toolbar {
  /* I'd prefer to have this centered */
  margin-top:   3px;
  margin-left:  3px;
  margin-right: 3px;
  /* This is ignored! */
	font-size: smaller;
  max-width: 20em;
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton] {
  border: 1px solid transparent;
  border-left: 1px solid darkgray;
  padding: 0px 4px 0px 4px;
  margin: 0px;
  /* Same as toolbar.standard titledbutton */
	color: #CCFFFF;
	background-color: #003366;
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton]:hover {
  border:  1px solid white;
  /* Alternate hover style: change background
  color: white;
  background-color: #66AAAA;
  */
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton]:active {
  color: black;
  background-color: #33FFFF;
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton][selected="1"] {
  border:  1px outset white;
  padding: 0px 4px 0px 4px;
  margin: -2px 0px 0px 0px;
  font-weight: bold;
  color: black;
	background-color: #CCCCCC;
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton][selected="1"]:hover {
  border:  1px solid white;
  /* Alternate hover style: change background
  background-color: #66AAAA;
  color: white;
  */
}

box#DisplayModeBar titledbutton[class~=DisplayModeButton][selected="1"]:active {
  background-color: #33FFFF;
  color: black;
}

box#DisplayModeBar div.VerticalSeparator { 
	 height: 100%; 
	 max-width: 1px; 
   border-left: 1px solid darkgray;
	 margin: 1px 0px;
}

spring.spacer3 {
      width:  3px;
      height: 3px;
}

spring.spacer5 {
      width:  5px;
      height: 5px;
}

/* Image URLs for all Editor toolbar buttons */

titledbutton#newButton {
	list-style-image:url("chrome://editor/skin/images/newfile.gif");
}
titledbutton#openButton {
	list-style-image:url("chrome://editor/skin/images/openfile.gif");
}

titledbutton#saveButton {
	list-style-image:url("chrome://editor/skin/images/savefile.gif");
}
titledbutton#saveButton[dirty="true"] {
  list-style-image:url(chrome://editor/skin/images/savemod.gif); 
}

titledbutton#publishButton {
	list-style-image:url("chrome://editor/skin/images/publish.gif");
}
titledbutton#printButton {
	list-style-image:url("chrome://editor/skin/images/print.gif");
}
titledbutton#findButton {
	list-style-image:url("chrome://editor/skin/images/find.gif");
}
titledbutton#linkButton {
	list-style-image:url("chrome://editor/skin/images/link.gif");
}
titledbutton#imageButton {
	list-style-image:url("chrome://editor/skin/images/image.gif");
}
titledbutton#namedAnchorButton {
	list-style-image:url("chrome://editor/skin/images/anchor.gif");
}
titledbutton#hlineButton {
	list-style-image:url("chrome://editor/skin/images/hline.gif");
}
titledbutton#tableButton {
	list-style-image:url("chrome://editor/skin/images/table.gif");
}
titledbutton#spellingButton {
	list-style-image:url("chrome://editor/skin/images/spell.gif");
}
titledbutton#ulButton {
	list-style-image:url("chrome://editor/skin/images/bullets.gif");
}
titledbutton#olButton {
	list-style-image:url("chrome://editor/skin/images/numbers.gif");
}
titledbutton#outdentButton {
	list-style-image:url("chrome://editor/skin/images/outdent.gif");
}
titledbutton#indentButton {
	list-style-image:url("chrome://editor/skin/images/indent.gif");
}
titledbutton#AlignPopupButton {
	list-style-image:url("chrome://editor/skin/images/align.gif");
}

/* Use negative margins to bring buttons together to look like one */
titledbutton#TextColorPopupButton {
	list-style-image:url("chrome://editor/skin/images/text-color.gif");
  border: 1px solid transparent;
  margin: 1px -1px 1px 1px;
  padding: 0px;
}
titledbutton#TextColorPopupButton:hover {
	list-style-image:url("chrome://editor/skin/images/text-color.gif");
  border: 1px solid white;
}

titledbutton#BackColorPopupButton {
	list-style-image:url("chrome://editor/skin/images/backcolor.gif");
  border: 1px solid transparent;
  margin: 1px 1px 1px -1px;
  padding: 0px;
}
titledbutton#BackColorPopupButton:hover {
	list-style-image:url("chrome://editor/skin/images/backcolor.gif");
  border: 1px solid white;
}

titledbutton#text-align-left {
	list-style-image:url("chrome://editor/skin/images/left.gif");
}
titledbutton#text-align-center {
	list-style-image:url("chrome://editor/skin/images/center.gif");
}
titledbutton#text-align-right {
	list-style-image:url("chrome://editor/skin/images/right.gif");
}
titledbutton#text-align-justify {
	list-style-image:url("chrome://editor/skin/images/justify.gif");
}
