/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 */

/*

  Style rules specific to the related links panel

*/

treeitem[container="true"][open="true"][loading="true"] > treerow > treecell > .tree-icon
{
    list-style-image: url("resource:/res/rdf/loading.gif") ! important ;
}

treeitem[container="true"][open="true"] > treerow > treecell > .tree-icon {
    list-style-image: url("resource:/res/rdf/folder-open.gif");
}

treeitem[container="true"] > treerow > treecell > .tree-icon {
    list-style-image: url("resource:/res/rdf/folder-closed.gif");
}

treeitem[container="true"][id="NC:SiteMapRoot"] > treerow > treecell > .tree-icon {
    list-style-image: url("chrome://related/skin/sitemap.gif");
}

treeitem[container="true"][open="true"][id="NC:SiteMapRoot"] > treerow > treecell > .tree-icon {
    list-style-image: url("chrome://related/skin/sitemap.gif");
}

treeitem > treerow > treecell > .tree-icon {
    list-style-image: url("chrome://bookmarks/skin/bookmark-item.gif");
}

treeitem > treerow > treecell > .tree-icon > .twisty{
  display: none;
}

/* Override rule in xul.css  */
treeitem[selected="true"] > treerow {
  color: inherit;
  background-color: inherit;
}
